<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:slides="http://cmsmcq.com/lib/tlslidy"
 		version="1.0">

  <xsl:import href="../../../lib/tlslidy.xsl"/>
  
  <xsl:param name="slides:copyright-year">MMXV</xsl:param>
  <xsl:param name="slides:css-addendum">../../../styles/bmtslidy.css</xsl:param>
  <xsl:param name="slides:slidyloc">../../../lib/Slidy</xsl:param>

  <xsl:output method="xhtml"/>

  <!--* experiment with slide headings *-->
 <xsl:template match="div2/head|body/div/div/head|back/div/div/head|front/div/div/head">
  <xsl:element name="h2">
   <xsl:attribute name="class">slidehead</xsl:attribute>
   <xsl:apply-templates/>
  </xsl:element>
 </xsl:template>

  <xsl:template match="del">
    <del style="text-decoration:  line-through;">
      <xsl:apply-templates/>
    </del>
  </xsl:template>

  <xsl:template match="eg/hi" priority="10">
    <span style="color: #888; font-style: italic;">
      <xsl:apply-templates/>
    </span>
  </xsl:template>

  <xsl:template match="hi[@rend='red']">
    <span style="color: red;"><xsl:apply-templates/></span>
  </xsl:template>

  <xsl:template match="hi[@rend='blue']">
    <span style="color: blue;"><xsl:apply-templates/></span>
  </xsl:template>

  <xsl:template match="lg">
    <div style="margin-left: 2em;">
      <xsl:apply-templates/>
    </div>
  </xsl:template>

  <xsl:template match="lg/l">
    <div style="margin: 0.2em 0;">
      <xsl:apply-templates/>
    </div>
  </xsl:template>

 <xsl:template match="figure[@rend='svg']" priority="2">
  <xsl:element name="object">
    <xsl:variable name="uri">
      <xsl:choose>
	<xsl:when test="function-available('unparsed-entity-uri') and
			not(unparsed-entity-uri(@entity) = '')">
	  <xsl:value-of select="unparsed-entity-uri(@entity)"/>
	</xsl:when>
	<xsl:otherwise>
	  <xsl:value-of select="concat('images/',@entity,'.svg')"/>
	</xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:attribute name="data">
      <xsl:value-of select="$uri"/>
    </xsl:attribute>
    <xsl:attribute name="src">
      <xsl:value-of select="unparsed-entity-uri(@entity)"/>
    </xsl:attribute>
    <xsl:attribute name="type">image/svg+xml</xsl:attribute>
    <xsl:attribute name="pluginspage">http://www.adobe.com/svg/viewer/install/</xsl:attribute>
    <xsl:attribute name="height">800</xsl:attribute>
    <xsl:attribute name="width">1600</xsl:attribute>
    <!--*
	<xsl:attribute name="width">100%</xsl:attribute>
	*-->
    <xsl:element name="img">
      <xsl:attribute name="src">
	<xsl:value-of select="concat(@entity, '.png')"/>
      </xsl:attribute>
    </xsl:element>
  </xsl:element>

  <xsl:apply-templates/>
 </xsl:template>

 <xsl:template match="seg[@lang='xpath']" priority="2">
   <xsl:element name="span">
     <xsl:attribute name="style">
       color: navy;
     </xsl:attribute>
     <xsl:apply-templates/>
   </xsl:element>
 </xsl:template>

 <xsl:template match="seg[@lang='input']" priority="2">
   <xsl:element name="span">
     <xsl:attribute name="style">
       color: green;
     </xsl:attribute>
     <xsl:apply-templates/>
   </xsl:element>
 </xsl:template>

 <xsl:template match="seg[@lang='pcdata']" priority="2">
   <xsl:element name="span">
     <xsl:attribute name="style">
       color: brown;
     </xsl:attribute>
     <xsl:apply-templates/>
   </xsl:element>
 </xsl:template>

 <xsl:template match="figure[following-sibling::*[1]/self::figure]" priority="1">
 <xsl:param name="force-uri">figure-it-out</xsl:param>
  <xsl:element name="blockquote">
   <xsl:if test="@id">
    <xsl:element name="a">
     <xsl:attribute name="name">
      <!--* xsl:value-of select="generate-id(.)"/> *-->
      <xsl:value-of select="@id"/>
     </xsl:attribute>
    </xsl:element>
   </xsl:if>
   <xsl:variable name="fig-uri">
    <xsl:choose>
     <xsl:when test="$force-uri != 'figure-it-out'">
      <xsl:value-of select="$force-uri"/>
     </xsl:when>
     <xsl:when test="function-available('unparsed-entity-uri') and
      not(unparsed-entity-uri(@entity) = '')">
      <xsl:value-of select="unparsed-entity-uri(@entity)"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="concat('images/',@entity,'.png')"/>
     </xsl:otherwise>
    </xsl:choose>
   </xsl:variable>
   <xsl:if test="not(function-available('unparsed-entity-uri'))">
    <xsl:comment>* This XSLT processor thinks the URI is '<xsl:value-of
      select="concat('images/',@entity,'.png')"/>' *</xsl:comment>
    <xsl:comment>* Unfortunately, this XSLT processor sucks. *</xsl:comment>
   </xsl:if>
   <xsl:if test="function-available('unparsed-entity-uri')">
    <xsl:comment>* This XSLT processor thinks the URI is '<xsl:value-of
      select="unparsed-entity-uri(@entity)"/>' *</xsl:comment>
   </xsl:if>
   <xsl:element name="p">
    <xsl:element name="img">
     <xsl:attribute name="src"><xsl:value-of select="$fig-uri"/></xsl:attribute>
     <!--* ugly hack, clean this up *-->
     <xsl:choose>
      <xsl:when test="@rend='large'">
       <xsl:attribute name="width">100%</xsl:attribute>
      </xsl:when>
      <xsl:when test="@rend != ''">
       <xsl:attribute name="width"><xsl:value-of select="@rend"/></xsl:attribute>
      </xsl:when>
      <xsl:otherwise>
       <xsl:attribute name="width">70%</xsl:attribute>
      </xsl:otherwise>
     </xsl:choose>
     <xsl:if test="./figDesc">
      <xsl:attribute name="alt"><xsl:value-of select="normalize-space(./figDesc)"/></xsl:attribute>
     </xsl:if>
    </xsl:element>
    <xsl:apply-templates/>
    <xsl:apply-templates select="following-sibling::*[1]" mode="figurepair"/>
   </xsl:element>
  </xsl:element>
 </xsl:template> 
 <xsl:template match="figure[preceding-sibling::*[1]/self::figure]" priority="1"/>
 <xsl:template match="figure[preceding-sibling::*[1]/self::figure]" mode="figurepair">
 <xsl:param name="force-uri">figure-it-out</xsl:param>
   <xsl:variable name="fig-uri">
    <xsl:choose>
     <xsl:when test="$force-uri != 'figure-it-out'">
      <xsl:value-of select="$force-uri"/>
     </xsl:when>
     <xsl:when test="function-available('unparsed-entity-uri') and
      not(unparsed-entity-uri(@entity) = '')">
      <xsl:value-of select="unparsed-entity-uri(@entity)"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="concat('images/',@entity,'.png')"/>
     </xsl:otherwise>
    </xsl:choose>
   </xsl:variable>
   <xsl:if test="not(function-available('unparsed-entity-uri'))">
    <xsl:comment>* This XSLT processor thinks the URI is '<xsl:value-of
      select="concat('images/',@entity,'.png')"/>' *</xsl:comment>
    <xsl:comment>* Unfortunately, this XSLT processor sucks. *</xsl:comment>
   </xsl:if>
   <xsl:if test="function-available('unparsed-entity-uri')">
    <xsl:comment>* This XSLT processor thinks the URI is '<xsl:value-of
      select="unparsed-entity-uri(@entity)"/>' *</xsl:comment>
   </xsl:if>
    <xsl:element name="img">
     <xsl:attribute name="src"><xsl:value-of select="$fig-uri"/></xsl:attribute>
     <xsl:attribute name="valign">top</xsl:attribute>
     <!--* ugly hack, clean this up *-->
     <xsl:choose>
      <xsl:when test="@rend='large'">
       <xsl:attribute name="width">100%</xsl:attribute>
      </xsl:when>
      <xsl:when test="@rend != ''">
       <xsl:attribute name="width"><xsl:value-of select="@rend"/></xsl:attribute>
      </xsl:when>
      <xsl:otherwise>
       <xsl:attribute name="width">70%</xsl:attribute>
      </xsl:otherwise>
     </xsl:choose>
     <xsl:if test="./figDesc">
      <xsl:attribute name="alt"><xsl:value-of select="normalize-space(./figDesc)"/></xsl:attribute>
     </xsl:if>
    </xsl:element>

   <xsl:apply-templates/>
 </xsl:template>

</xsl:stylesheet>